/**
 * Imperative (procedural) function to display fomantic 'toast' component.
 * @module components/proc-toast
 */
import { SettingsHelper } from "../data/settings";
import { jQueryElem } from "../data/common";
/*
   dP                                dP
   88                                88
 d8888P .d8888b. .d8888b. .d8888b. d8888P
   88   88'  `88 88'  `88 Y8ooooo.   88
   88   88.  .88 88.  .88       88   88
   dP   `88888P' `88888P8 `88888P'   dP

*/
/** Default toast settings */
export const toastDefaults = new SettingsHelper("toast");
/** Imperative function to display Semantic UI Toast component.
 *
 * https://fomantic-ui.com/modules/toast.html
 *
 * Example:
```
    <script>
        toast({
            class: 'success',
            title: 'Better?',
            message: `You're using the good framework!`,
            displayTime: 5000,
        });
    <script>
```
*/
export function toast(settings) {
    console.debug("toast - created");
    const body = jQueryElem(document.body);
    if (!body.toast) {
        throw new Error("Semantic toast is not initialized");
    }
    body.toast({
        // ...toastDefaults,
        ...settings,
    });
}
