/**
 * Svelte action to initialize semantic checkbox component.
 * @module components/use-checkbox
 */
import { SettingsHelper } from "../data/settings";
import { jQueryElem } from "../data/common";
export const checkboxDefaults = new SettingsHelper("checkbox");
/** Svelte action to initialize Semantic UI Checkbox component.
 *
 * https://semantic-ui.com/modules/checkbox.html
 *
 * Bind directly to the input ```bind:checked```.
 *
 * Example:
```
    <div class="ui checkbox" use:checkbox>
        <input type="checkbox" id="ch" bind:checked={agree} />
        <label for="ch">Agree to terms and Conditions</label>
    </div>
```
*/
export function checkbox(node, settings) {
    const elem = jQueryElem(node);
    if (!elem.checkbox) {
        throw new Error("Semantic checkbox is not initialized");
    }
    elem.checkbox({
        // ...checkboxDefaults,
        ...settings,
    });
}
