/**
 * Svelte action to initialize semantic modal dialogue component.
 * @module components/use-modal
 */
import type { ActionReturnType } from "../data/common";
import type { ModalSettings } from "../data/semantic-types";
import { SettingsHelper } from "../data/settings";
export declare const modalDefaults: SettingsHelper<ModalSettings>;
/**
 * Initializes Semantic UI Modal componenet. Takes settings object as argument.
 *
 * https://semantic-ui.com/modules/modal.html
 *
 * Example:
```
    <div class="ui basic modal"
        use:modal={{ onApprove: okFn, closable: false }}>
        <Data bind:active={show} />
        ...
    </div>
```
or
```
    <div  class="ui basic modal"
        use:modal={{ onApprove: okFn, closable: false }}>
        use:controller={ctrl} />
        ...
    </div>
    <script>
        ctrl.modal("show");
    </script>
```
*/
export declare function modal(node: Element, settings?: ModalSettings): ActionReturnType;
